# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.role_permission import RolePermission  # noqa: F401,E501
from teralytic.models.uuid_array import UUIDArray  # noqa: F401,E501


class PropertyRole(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'user_id': 'str',
        'property_id': 'str',
        'permission_ids': 'UUIDArray',
        'permissions': 'list[RolePermission]'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'user_id',
        'property_id': 'property_id',
        'permission_ids': 'permission_ids',
        'permissions': 'permissions'
    }

    def __init__(self, id=None, user_id=None, property_id=None, permission_ids=None, permissions=None):  # noqa: E501
        """PropertyRole - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._user_id = None
        self._property_id = None
        self._permission_ids = None
        self._permissions = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if property_id is not None:
            self.property_id = property_id
        if permission_ids is not None:
            self.permission_ids = permission_ids
        if permissions is not None:
            self.permissions = permissions

    @property
    def id(self):
        """Gets the id of this PropertyRole.  # noqa: E501

        Role id  # noqa: E501

        :return: The id of this PropertyRole.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PropertyRole.

        Role id  # noqa: E501

        :param id: The id of this PropertyRole.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PropertyRole.  # noqa: E501

        The user id  # noqa: E501

        :return: The user_id of this PropertyRole.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PropertyRole.

        The user id  # noqa: E501

        :param user_id: The user_id of this PropertyRole.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def property_id(self):
        """Gets the property_id of this PropertyRole.  # noqa: E501

        The property id  # noqa: E501

        :return: The property_id of this PropertyRole.  # noqa: E501
        :rtype: str
        """
        return self._property_id

    @property_id.setter
    def property_id(self, property_id):
        """Sets the property_id of this PropertyRole.

        The property id  # noqa: E501

        :param property_id: The property_id of this PropertyRole.  # noqa: E501
        :type: str
        """

        self._property_id = property_id

    @property
    def permission_ids(self):
        """Gets the permission_ids of this PropertyRole.  # noqa: E501


        :return: The permission_ids of this PropertyRole.  # noqa: E501
        :rtype: UUIDArray
        """
        return self._permission_ids

    @permission_ids.setter
    def permission_ids(self, permission_ids):
        """Sets the permission_ids of this PropertyRole.


        :param permission_ids: The permission_ids of this PropertyRole.  # noqa: E501
        :type: UUIDArray
        """

        self._permission_ids = permission_ids

    @property
    def permissions(self):
        """Gets the permissions of this PropertyRole.  # noqa: E501


        :return: The permissions of this PropertyRole.  # noqa: E501
        :rtype: list[RolePermission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this PropertyRole.


        :param permissions: The permissions of this PropertyRole.  # noqa: E501
        :type: list[RolePermission]
        """

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PropertyRole, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PropertyRole):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.reading_data import ReadingData  # noqa: F401,E501


class WeatherData(ReadingData):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'weather_summary': 'str',
        'precip_type': 'str',
        'apparent_temp': 'float',
        'cloud_cover': 'float',
        'dew_point': 'float',
        'humidity': 'float',
        'ozone': 'float',
        'precip_intensity': 'float',
        'precip_probability': 'float',
        'pressure': 'float',
        'temperature': 'float',
        'time': 'float',
        'uv_index': 'int',
        'wind_bearing': 'int',
        'wind_gust': 'float',
        'wind_speed': 'float',
        'visibility': 'float'
    }

    attribute_map = {
        'weather_summary': 'weather_summary',
        'precip_type': 'precip_type',
        'apparent_temp': 'apparent_temp',
        'cloud_cover': 'cloud_cover',
        'dew_point': 'dew_point',
        'humidity': 'humidity',
        'ozone': 'ozone',
        'precip_intensity': 'precip_intensity',
        'precip_probability': 'precip_probability',
        'pressure': 'pressure',
        'temperature': 'temperature',
        'time': 'time',
        'uv_index': 'uv_index',
        'wind_bearing': 'wind_bearing',
        'wind_gust': 'wind_gust',
        'wind_speed': 'wind_speed',
        'visibility': 'visibility'
    }

    def __init__(self, weather_summary=None, precip_type=None, apparent_temp=None, cloud_cover=None, dew_point=None, humidity=None, ozone=None, precip_intensity=None, precip_probability=None, pressure=None, temperature=None, time=None, uv_index=None, wind_bearing=None, wind_gust=None, wind_speed=None, visibility=None):  # noqa: E501
        """WeatherData - a model defined in Swagger"""  # noqa: E501

        self._weather_summary = None
        self._precip_type = None
        self._apparent_temp = None
        self._cloud_cover = None
        self._dew_point = None
        self._humidity = None
        self._ozone = None
        self._precip_intensity = None
        self._precip_probability = None
        self._pressure = None
        self._temperature = None
        self._time = None
        self._uv_index = None
        self._wind_bearing = None
        self._wind_gust = None
        self._wind_speed = None
        self._visibility = None
        self.discriminator = None

        if weather_summary is not None:
            self.weather_summary = weather_summary
        if precip_type is not None:
            self.precip_type = precip_type
        if apparent_temp is not None:
            self.apparent_temp = apparent_temp
        if cloud_cover is not None:
            self.cloud_cover = cloud_cover
        if dew_point is not None:
            self.dew_point = dew_point
        if humidity is not None:
            self.humidity = humidity
        if ozone is not None:
            self.ozone = ozone
        if precip_intensity is not None:
            self.precip_intensity = precip_intensity
        if precip_probability is not None:
            self.precip_probability = precip_probability
        if pressure is not None:
            self.pressure = pressure
        if temperature is not None:
            self.temperature = temperature
        if time is not None:
            self.time = time
        if uv_index is not None:
            self.uv_index = uv_index
        if wind_bearing is not None:
            self.wind_bearing = wind_bearing
        if wind_gust is not None:
            self.wind_gust = wind_gust
        if wind_speed is not None:
            self.wind_speed = wind_speed
        if visibility is not None:
            self.visibility = visibility

    @property
    def weather_summary(self):
        """Gets the weather_summary of this WeatherData.  # noqa: E501

        Weather Summary  # noqa: E501

        :return: The weather_summary of this WeatherData.  # noqa: E501
        :rtype: str
        """
        return self._weather_summary

    @weather_summary.setter
    def weather_summary(self, weather_summary):
        """Sets the weather_summary of this WeatherData.

        Weather Summary  # noqa: E501

        :param weather_summary: The weather_summary of this WeatherData.  # noqa: E501
        :type: str
        """

        self._weather_summary = weather_summary

    @property
    def precip_type(self):
        """Gets the precip_type of this WeatherData.  # noqa: E501

        Precipitation Type  # noqa: E501

        :return: The precip_type of this WeatherData.  # noqa: E501
        :rtype: str
        """
        return self._precip_type

    @precip_type.setter
    def precip_type(self, precip_type):
        """Sets the precip_type of this WeatherData.

        Precipitation Type  # noqa: E501

        :param precip_type: The precip_type of this WeatherData.  # noqa: E501
        :type: str
        """

        self._precip_type = precip_type

    @property
    def apparent_temp(self):
        """Gets the apparent_temp of this WeatherData.  # noqa: E501

        Apparent Temperature  # noqa: E501

        :return: The apparent_temp of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._apparent_temp

    @apparent_temp.setter
    def apparent_temp(self, apparent_temp):
        """Sets the apparent_temp of this WeatherData.

        Apparent Temperature  # noqa: E501

        :param apparent_temp: The apparent_temp of this WeatherData.  # noqa: E501
        :type: float
        """

        self._apparent_temp = apparent_temp

    @property
    def cloud_cover(self):
        """Gets the cloud_cover of this WeatherData.  # noqa: E501

        Cloud Cover  # noqa: E501

        :return: The cloud_cover of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._cloud_cover

    @cloud_cover.setter
    def cloud_cover(self, cloud_cover):
        """Sets the cloud_cover of this WeatherData.

        Cloud Cover  # noqa: E501

        :param cloud_cover: The cloud_cover of this WeatherData.  # noqa: E501
        :type: float
        """

        self._cloud_cover = cloud_cover

    @property
    def dew_point(self):
        """Gets the dew_point of this WeatherData.  # noqa: E501

        Dew Point  # noqa: E501

        :return: The dew_point of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._dew_point

    @dew_point.setter
    def dew_point(self, dew_point):
        """Sets the dew_point of this WeatherData.

        Dew Point  # noqa: E501

        :param dew_point: The dew_point of this WeatherData.  # noqa: E501
        :type: float
        """

        self._dew_point = dew_point

    @property
    def humidity(self):
        """Gets the humidity of this WeatherData.  # noqa: E501

        Humidity  # noqa: E501

        :return: The humidity of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._humidity

    @humidity.setter
    def humidity(self, humidity):
        """Sets the humidity of this WeatherData.

        Humidity  # noqa: E501

        :param humidity: The humidity of this WeatherData.  # noqa: E501
        :type: float
        """

        self._humidity = humidity

    @property
    def ozone(self):
        """Gets the ozone of this WeatherData.  # noqa: E501

        Ozone Rating  # noqa: E501

        :return: The ozone of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._ozone

    @ozone.setter
    def ozone(self, ozone):
        """Sets the ozone of this WeatherData.

        Ozone Rating  # noqa: E501

        :param ozone: The ozone of this WeatherData.  # noqa: E501
        :type: float
        """

        self._ozone = ozone

    @property
    def precip_intensity(self):
        """Gets the precip_intensity of this WeatherData.  # noqa: E501

        Precipitation Intesity  # noqa: E501

        :return: The precip_intensity of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._precip_intensity

    @precip_intensity.setter
    def precip_intensity(self, precip_intensity):
        """Sets the precip_intensity of this WeatherData.

        Precipitation Intesity  # noqa: E501

        :param precip_intensity: The precip_intensity of this WeatherData.  # noqa: E501
        :type: float
        """

        self._precip_intensity = precip_intensity

    @property
    def precip_probability(self):
        """Gets the precip_probability of this WeatherData.  # noqa: E501

        Precipitation Probability  # noqa: E501

        :return: The precip_probability of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._precip_probability

    @precip_probability.setter
    def precip_probability(self, precip_probability):
        """Sets the precip_probability of this WeatherData.

        Precipitation Probability  # noqa: E501

        :param precip_probability: The precip_probability of this WeatherData.  # noqa: E501
        :type: float
        """

        self._precip_probability = precip_probability

    @property
    def pressure(self):
        """Gets the pressure of this WeatherData.  # noqa: E501

        Barometric Pressure  # noqa: E501

        :return: The pressure of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._pressure

    @pressure.setter
    def pressure(self, pressure):
        """Sets the pressure of this WeatherData.

        Barometric Pressure  # noqa: E501

        :param pressure: The pressure of this WeatherData.  # noqa: E501
        :type: float
        """

        self._pressure = pressure

    @property
    def temperature(self):
        """Gets the temperature of this WeatherData.  # noqa: E501

        Temperature  # noqa: E501

        :return: The temperature of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this WeatherData.

        Temperature  # noqa: E501

        :param temperature: The temperature of this WeatherData.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def time(self):
        """Gets the time of this WeatherData.  # noqa: E501

        Weather Sample Time (epoch)  # noqa: E501

        :return: The time of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this WeatherData.

        Weather Sample Time (epoch)  # noqa: E501

        :param time: The time of this WeatherData.  # noqa: E501
        :type: float
        """

        self._time = time

    @property
    def uv_index(self):
        """Gets the uv_index of this WeatherData.  # noqa: E501

        UV Index  # noqa: E501

        :return: The uv_index of this WeatherData.  # noqa: E501
        :rtype: int
        """
        return self._uv_index

    @uv_index.setter
    def uv_index(self, uv_index):
        """Sets the uv_index of this WeatherData.

        UV Index  # noqa: E501

        :param uv_index: The uv_index of this WeatherData.  # noqa: E501
        :type: int
        """

        self._uv_index = uv_index

    @property
    def wind_bearing(self):
        """Gets the wind_bearing of this WeatherData.  # noqa: E501

        Wind Bearing  # noqa: E501

        :return: The wind_bearing of this WeatherData.  # noqa: E501
        :rtype: int
        """
        return self._wind_bearing

    @wind_bearing.setter
    def wind_bearing(self, wind_bearing):
        """Sets the wind_bearing of this WeatherData.

        Wind Bearing  # noqa: E501

        :param wind_bearing: The wind_bearing of this WeatherData.  # noqa: E501
        :type: int
        """

        self._wind_bearing = wind_bearing

    @property
    def wind_gust(self):
        """Gets the wind_gust of this WeatherData.  # noqa: E501

        Wind Gust  # noqa: E501

        :return: The wind_gust of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._wind_gust

    @wind_gust.setter
    def wind_gust(self, wind_gust):
        """Sets the wind_gust of this WeatherData.

        Wind Gust  # noqa: E501

        :param wind_gust: The wind_gust of this WeatherData.  # noqa: E501
        :type: float
        """

        self._wind_gust = wind_gust

    @property
    def wind_speed(self):
        """Gets the wind_speed of this WeatherData.  # noqa: E501

        Wind Speed  # noqa: E501

        :return: The wind_speed of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._wind_speed

    @wind_speed.setter
    def wind_speed(self, wind_speed):
        """Sets the wind_speed of this WeatherData.

        Wind Speed  # noqa: E501

        :param wind_speed: The wind_speed of this WeatherData.  # noqa: E501
        :type: float
        """

        self._wind_speed = wind_speed

    @property
    def visibility(self):
        """Gets the visibility of this WeatherData.  # noqa: E501

        Visibility  # noqa: E501

        :return: The visibility of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this WeatherData.

        Visibility  # noqa: E501

        :param visibility: The visibility of this WeatherData.  # noqa: E501
        :type: float
        """

        self._visibility = visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WeatherData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WeatherData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.org_role import OrgRole  # noqa: F401,E501
from teralytic.models.property_role import PropertyRole  # noqa: F401,E501
from teralytic.models.uuid_array import UUIDArray  # noqa: F401,E501


class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'organizations': 'UUIDArray',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'email_verified': 'bool',
        'username': 'str',
        'org_roles': 'list[OrgRole]',
        'property_roles': 'list[PropertyRole]'
    }

    attribute_map = {
        'id': 'id',
        'organizations': 'organizations',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'email': 'email',
        'email_verified': 'email_verified',
        'username': 'username',
        'org_roles': 'org_roles',
        'property_roles': 'property_roles'
    }

    def __init__(self, id=None, organizations=None, first_name=None, last_name=None, email=None, email_verified=None, username=None, org_roles=None, property_roles=None):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._organizations = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._email_verified = None
        self._username = None
        self._org_roles = None
        self._property_roles = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if organizations is not None:
            self.organizations = organizations
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if email_verified is not None:
            self.email_verified = email_verified
        if username is not None:
            self.username = username
        if org_roles is not None:
            self.org_roles = org_roles
        if property_roles is not None:
            self.property_roles = property_roles

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501

        The users uuid  # noqa: E501

        :return: The id of this User.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.

        The users uuid  # noqa: E501

        :param id: The id of this User.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def organizations(self):
        """Gets the organizations of this User.  # noqa: E501


        :return: The organizations of this User.  # noqa: E501
        :rtype: UUIDArray
        """
        return self._organizations

    @organizations.setter
    def organizations(self, organizations):
        """Sets the organizations of this User.


        :param organizations: The organizations of this User.  # noqa: E501
        :type: UUIDArray
        """

        self._organizations = organizations

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501

        The user's first name  # noqa: E501

        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.

        The user's first name  # noqa: E501

        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501

        The user's last name  # noqa: E501

        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.

        The user's last name  # noqa: E501

        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this User.  # noqa: E501

        The user's email address  # noqa: E501

        :return: The email of this User.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this User.

        The user's email address  # noqa: E501

        :param email: The email of this User.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def email_verified(self):
        """Gets the email_verified of this User.  # noqa: E501

        Set if the user's email address is verified  # noqa: E501

        :return: The email_verified of this User.  # noqa: E501
        :rtype: bool
        """
        return self._email_verified

    @email_verified.setter
    def email_verified(self, email_verified):
        """Sets the email_verified of this User.

        Set if the user's email address is verified  # noqa: E501

        :param email_verified: The email_verified of this User.  # noqa: E501
        :type: bool
        """

        self._email_verified = email_verified

    @property
    def username(self):
        """Gets the username of this User.  # noqa: E501

        The users login name  # noqa: E501

        :return: The username of this User.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this User.

        The users login name  # noqa: E501

        :param username: The username of this User.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def org_roles(self):
        """Gets the org_roles of this User.  # noqa: E501


        :return: The org_roles of this User.  # noqa: E501
        :rtype: list[OrgRole]
        """
        return self._org_roles

    @org_roles.setter
    def org_roles(self, org_roles):
        """Sets the org_roles of this User.


        :param org_roles: The org_roles of this User.  # noqa: E501
        :type: list[OrgRole]
        """

        self._org_roles = org_roles

    @property
    def property_roles(self):
        """Gets the property_roles of this User.  # noqa: E501


        :return: The property_roles of this User.  # noqa: E501
        :rtype: list[PropertyRole]
        """
        return self._property_roles

    @property_roles.setter
    def property_roles(self, property_roles):
        """Sets the property_roles of this User.


        :param property_roles: The property_roles of this User.  # noqa: E501
        :type: list[PropertyRole]
        """

        self._property_roles = property_roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.models.uuid_array import UUIDArray  # noqa: E501
from teralytic.rest import ApiException


class TestUUIDArray(unittest.TestCase):
    """UUIDArray unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUUIDArray(self):
        """Test UUIDArray"""
        # FIXME: construct object with mandatory attributes with example values
        # model = teralytic.models.uuid_array.UUIDArray()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.field_geometry import FieldGeometry  # noqa: F401,E501


class Field(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'organization_id': 'str',
        'name': 'str',
        'acreage': 'float',
        'crop': 'str',
        'geometry': 'FieldGeometry'
    }

    attribute_map = {
        'id': 'id',
        'organization_id': 'organization_id',
        'name': 'name',
        'acreage': 'acreage',
        'crop': 'crop',
        'geometry': 'geometry'
    }

    def __init__(self, id=None, organization_id=None, name=None, acreage=None, crop=None, geometry=None):  # noqa: E501
        """Field - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._organization_id = None
        self._name = None
        self._acreage = None
        self._crop = None
        self._geometry = None
        self.discriminator = None

        self.id = id
        if organization_id is not None:
            self.organization_id = organization_id
        self.name = name
        if acreage is not None:
            self.acreage = acreage
        if crop is not None:
            self.crop = crop
        if geometry is not None:
            self.geometry = geometry

    @property
    def id(self):
        """Gets the id of this Field.  # noqa: E501


        :return: The id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Field.


        :param id: The id of this Field.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def organization_id(self):
        """Gets the organization_id of this Field.  # noqa: E501


        :return: The organization_id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this Field.


        :param organization_id: The organization_id of this Field.  # noqa: E501
        :type: str
        """

        self._organization_id = organization_id

    @property
    def name(self):
        """Gets the name of this Field.  # noqa: E501


        :return: The name of this Field.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Field.


        :param name: The name of this Field.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def acreage(self):
        """Gets the acreage of this Field.  # noqa: E501


        :return: The acreage of this Field.  # noqa: E501
        :rtype: float
        """
        return self._acreage

    @acreage.setter
    def acreage(self, acreage):
        """Sets the acreage of this Field.


        :param acreage: The acreage of this Field.  # noqa: E501
        :type: float
        """

        self._acreage = acreage

    @property
    def crop(self):
        """Gets the crop of this Field.  # noqa: E501


        :return: The crop of this Field.  # noqa: E501
        :rtype: str
        """
        return self._crop

    @crop.setter
    def crop(self, crop):
        """Sets the crop of this Field.


        :param crop: The crop of this Field.  # noqa: E501
        :type: str
        """

        self._crop = crop

    @property
    def geometry(self):
        """Gets the geometry of this Field.  # noqa: E501


        :return: The geometry of this Field.  # noqa: E501
        :rtype: FieldGeometry
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this Field.


        :param geometry: The geometry of this Field.  # noqa: E501
        :type: FieldGeometry
        """

        self._geometry = geometry

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Field, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Field):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teralytic.api_client import ApiClient


class OrganizationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def application_create(self, organization_id, **kwargs):  # noqa: E501
        """Create a new organization client with the specified scope  # noqa: E501

        Create a new third-party application client  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_create(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization for the operation (required)
        :param Application application: The application to create
        :return: Application
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_create_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.application_create_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def application_create_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """Create a new organization client with the specified scope  # noqa: E501

        Create a new third-party application client  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_create_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization for the operation (required)
        :param Application application: The application to create
        :return: Application
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'application']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `application_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'application' in params:
            body_params = params['application']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/applications', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Application',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def application_delete(self, organization_id, application_id, **kwargs):  # noqa: E501
        """Delete an application api client  # noqa: E501

        Delete an application client for the organization from the database  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_delete(organization_id, application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization for the operation (required)
        :param str application_id: id of application to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_delete_with_http_info(organization_id, application_id, **kwargs)  # noqa: E501
        else:
            (data) = self.application_delete_with_http_info(organization_id, application_id, **kwargs)  # noqa: E501
            return data

    def application_delete_with_http_info(self, organization_id, application_id, **kwargs):  # noqa: E501
        """Delete an application api client  # noqa: E501

        Delete an application client for the organization from the database  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_delete_with_http_info(organization_id, application_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization for the operation (required)
        :param str application_id: id of application to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'application_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `application_delete`")  # noqa: E501
        # verify the required parameter 'application_id' is set
        if ('application_id' not in params or
                params['application_id'] is None):
            raise ValueError("Missing the required parameter `application_id` when calling `application_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501
        if 'application_id' in params:
            path_params['application_id'] = params['application_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/applications/{application_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def application_list(self, organization_id, **kwargs):  # noqa: E501
        """Get organization applications  # noqa: E501

        List all applications for an organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_list(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization for the operation (required)
        :return: list[Application]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_list_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.application_list_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def application_list_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """Get organization applications  # noqa: E501

        List all applications for an organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_list_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization for the operation (required)
        :return: list[Application]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `application_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/applications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Application]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def field_get(self, organization_id, field_id, **kwargs):  # noqa: E501
        """List single Field details associated with Field id provided (from set of Fields associated with the account key)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.field_get(organization_id, field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param str field_id: id of Field to retrieve (required)
        :return: Field
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.field_get_with_http_info(organization_id, field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.field_get_with_http_info(organization_id, field_id, **kwargs)  # noqa: E501
            return data

    def field_get_with_http_info(self, organization_id, field_id, **kwargs):  # noqa: E501
        """List single Field details associated with Field id provided (from set of Fields associated with the account key)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.field_get_with_http_info(organization_id, field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param str field_id: id of Field to retrieve (required)
        :return: Field
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'field_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method field_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `field_get`")  # noqa: E501
        # verify the required parameter 'field_id' is set
        if ('field_id' not in params or
                params['field_id'] is None):
            raise ValueError("Missing the required parameter `field_id` when calling `field_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501
        if 'field_id' in params:
            path_params['field_id'] = params['field_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/fields/{field_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Field',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def field_list(self, organization_id, **kwargs):  # noqa: E501
        """List all Fields associated with account key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.field_list(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param list[str] points: Array of points (lat,lng) describing a polygon search pattern.
        :return: list[Field]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.field_list_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.field_list_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def field_list_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """List all Fields associated with account key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.field_list_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param list[str] points: Array of points (lat,lng) describing a polygon search pattern.
        :return: list[Field]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'points']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method field_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `field_list`")  # noqa: E501

        if ('points' in params and
                len(params['points']) < 3):
            raise ValueError("Invalid value for parameter `points` when calling `field_list`, number of items must be greater than or equal to `3`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []
        if 'points' in params:
            query_params.append(('points', params['points']))  # noqa: E501
            collection_formats['points'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/fields', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Field]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organization_get(self, organization_id, **kwargs):  # noqa: E501
        """Get a specific organization  # noqa: E501

        List single Organization details associated with Organization id provided  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organization_get(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organization_get_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organization_get_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def organization_get_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """Get a specific organization  # noqa: E501

        List single Organization details associated with Organization id provided  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organization_get_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organization_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `organization_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organization_list(self, **kwargs):  # noqa: E501
        """List all Organizations  # noqa: E501

        Lists all organization, requires admin scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organization_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Organization]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organization_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.organization_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def organization_list_with_http_info(self, **kwargs):  # noqa: E501
        """List all Organizations  # noqa: E501

        Lists all organization, requires admin scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organization_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Organization]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organization_list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Organization]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def probe_get(self, organization_id, probe_id, **kwargs):  # noqa: E501
        """List single Probe details, including Reading data, associated with Probe id provided (from set of Fields associated with the account key)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.probe_get(organization_id, probe_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param str probe_id: id of Probe to retrieve (required)
        :return: Probe
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.probe_get_with_http_info(organization_id, probe_id, **kwargs)  # noqa: E501
        else:
            (data) = self.probe_get_with_http_info(organization_id, probe_id, **kwargs)  # noqa: E501
            return data

    def probe_get_with_http_info(self, organization_id, probe_id, **kwargs):  # noqa: E501
        """List single Probe details, including Reading data, associated with Probe id provided (from set of Fields associated with the account key)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.probe_get_with_http_info(organization_id, probe_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param str probe_id: id of Probe to retrieve (required)
        :return: Probe
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'probe_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method probe_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `probe_get`")  # noqa: E501
        # verify the required parameter 'probe_id' is set
        if ('probe_id' not in params or
                params['probe_id'] is None):
            raise ValueError("Missing the required parameter `probe_id` when calling `probe_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501
        if 'probe_id' in params:
            path_params['probe_id'] = params['probe_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/probes/{probe_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Probe',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def probe_list(self, organization_id, **kwargs):  # noqa: E501
        """List all Probes associated with account key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.probe_list(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param list[str] fields: Fields to filter search on
        :return: list[Probe]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.probe_list_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.probe_list_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def probe_list_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """List all Probes associated with account key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.probe_list_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param list[str] fields: Fields to filter search on
        :return: list[Probe]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method probe_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `probe_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501
            collection_formats['fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/probes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Probe]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.reading_data import ReadingData  # noqa: F401,E501
from teralytic.models.reading_location import ReadingLocation  # noqa: F401,E501


class Reading(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'probe_id': 'str',
        'probe_name': 'str',
        'field_id': 'str',
        'timestamp': 'str',
        'location': 'ReadingLocation',
        'operation': 'str',
        'readings': 'list[ReadingData]'
    }

    attribute_map = {
        'id': 'id',
        'probe_id': 'probe_id',
        'probe_name': 'probe_name',
        'field_id': 'field_id',
        'timestamp': 'timestamp',
        'location': 'location',
        'operation': 'operation',
        'readings': 'readings'
    }

    def __init__(self, id=None, probe_id=None, probe_name=None, field_id=None, timestamp=None, location=None, operation=None, readings=None):  # noqa: E501
        """Reading - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._probe_id = None
        self._probe_name = None
        self._field_id = None
        self._timestamp = None
        self._location = None
        self._operation = None
        self._readings = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if probe_id is not None:
            self.probe_id = probe_id
        if probe_name is not None:
            self.probe_name = probe_name
        if field_id is not None:
            self.field_id = field_id
        if timestamp is not None:
            self.timestamp = timestamp
        if location is not None:
            self.location = location
        if operation is not None:
            self.operation = operation
        if readings is not None:
            self.readings = readings

    @property
    def id(self):
        """Gets the id of this Reading.  # noqa: E501

        Base58 encoded identifier for this reading. Corresponds with a single Probe and single timestamp.  # noqa: E501

        :return: The id of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Reading.

        Base58 encoded identifier for this reading. Corresponds with a single Probe and single timestamp.  # noqa: E501

        :param id: The id of this Reading.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def probe_id(self):
        """Gets the probe_id of this Reading.  # noqa: E501

        id of probe from which Reading was made  # noqa: E501

        :return: The probe_id of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this Reading.

        id of probe from which Reading was made  # noqa: E501

        :param probe_id: The probe_id of this Reading.  # noqa: E501
        :type: str
        """

        self._probe_id = probe_id

    @property
    def probe_name(self):
        """Gets the probe_name of this Reading.  # noqa: E501

        Name of probe from which Reading was made  # noqa: E501

        :return: The probe_name of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._probe_name

    @probe_name.setter
    def probe_name(self, probe_name):
        """Sets the probe_name of this Reading.

        Name of probe from which Reading was made  # noqa: E501

        :param probe_name: The probe_name of this Reading.  # noqa: E501
        :type: str
        """

        self._probe_name = probe_name

    @property
    def field_id(self):
        """Gets the field_id of this Reading.  # noqa: E501

        The field id of the probe  # noqa: E501

        :return: The field_id of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Reading.

        The field id of the probe  # noqa: E501

        :param field_id: The field_id of this Reading.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def timestamp(self):
        """Gets the timestamp of this Reading.  # noqa: E501

        Time when Reading was measured  # noqa: E501

        :return: The timestamp of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Reading.

        Time when Reading was measured  # noqa: E501

        :param timestamp: The timestamp of this Reading.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def location(self):
        """Gets the location of this Reading.  # noqa: E501


        :return: The location of this Reading.  # noqa: E501
        :rtype: ReadingLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Reading.


        :param location: The location of this Reading.  # noqa: E501
        :type: ReadingLocation
        """

        self._location = location

    @property
    def operation(self):
        """Gets the operation of this Reading.  # noqa: E501

        The analytics operation  # noqa: E501

        :return: The operation of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this Reading.

        The analytics operation  # noqa: E501

        :param operation: The operation of this Reading.  # noqa: E501
        :type: str
        """

        self._operation = operation

    @property
    def readings(self):
        """Gets the readings of this Reading.  # noqa: E501

        Probe readings  # noqa: E501

        :return: The readings of this Reading.  # noqa: E501
        :rtype: list[ReadingData]
        """
        return self._readings

    @readings.setter
    def readings(self, readings):
        """Sets the readings of this Reading.

        Probe readings  # noqa: E501

        :param readings: The readings of this Reading.  # noqa: E501
        :type: list[ReadingData]
        """

        self._readings = readings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Reading, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Reading):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ReadingLocation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'latitude': 'float',
        'longitude': 'float',
        'geohash': 'str'
    }

    attribute_map = {
        'latitude': 'latitude',
        'longitude': 'longitude',
        'geohash': 'geohash'
    }

    def __init__(self, latitude=None, longitude=None, geohash=None):  # noqa: E501
        """ReadingLocation - a model defined in Swagger"""  # noqa: E501

        self._latitude = None
        self._longitude = None
        self._geohash = None
        self.discriminator = None

        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude
        if geohash is not None:
            self.geohash = geohash

    @property
    def latitude(self):
        """Gets the latitude of this ReadingLocation.  # noqa: E501


        :return: The latitude of this ReadingLocation.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this ReadingLocation.


        :param latitude: The latitude of this ReadingLocation.  # noqa: E501
        :type: float
        """

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this ReadingLocation.  # noqa: E501


        :return: The longitude of this ReadingLocation.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this ReadingLocation.


        :param longitude: The longitude of this ReadingLocation.  # noqa: E501
        :type: float
        """

        self._longitude = longitude

    @property
    def geohash(self):
        """Gets the geohash of this ReadingLocation.  # noqa: E501

        location geohash (12 digit precision)  # noqa: E501

        :return: The geohash of this ReadingLocation.  # noqa: E501
        :rtype: str
        """
        return self._geohash

    @geohash.setter
    def geohash(self, geohash):
        """Sets the geohash of this ReadingLocation.

        location geohash (12 digit precision)  # noqa: E501

        :param geohash: The geohash of this ReadingLocation.  # noqa: E501
        :type: str
        """

        self._geohash = geohash

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReadingLocation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReadingLocation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.role_permission import RolePermission  # noqa: F401,E501
from teralytic.models.uuid_array import UUIDArray  # noqa: F401,E501


class OrgRole(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'user_id': 'str',
        'organization_id': 'str',
        'permission_ids': 'UUIDArray',
        'permissions': 'list[RolePermission]',
        'owner': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'user_id',
        'organization_id': 'organization_id',
        'permission_ids': 'permission_ids',
        'permissions': 'permissions',
        'owner': 'owner'
    }

    def __init__(self, id=None, user_id=None, organization_id=None, permission_ids=None, permissions=None, owner=None):  # noqa: E501
        """OrgRole - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._user_id = None
        self._organization_id = None
        self._permission_ids = None
        self._permissions = None
        self._owner = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if organization_id is not None:
            self.organization_id = organization_id
        if permission_ids is not None:
            self.permission_ids = permission_ids
        if permissions is not None:
            self.permissions = permissions
        if owner is not None:
            self.owner = owner

    @property
    def id(self):
        """Gets the id of this OrgRole.  # noqa: E501

        Role id  # noqa: E501

        :return: The id of this OrgRole.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrgRole.

        Role id  # noqa: E501

        :param id: The id of this OrgRole.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this OrgRole.  # noqa: E501

        The user id  # noqa: E501

        :return: The user_id of this OrgRole.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this OrgRole.

        The user id  # noqa: E501

        :param user_id: The user_id of this OrgRole.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def organization_id(self):
        """Gets the organization_id of this OrgRole.  # noqa: E501

        The organization id  # noqa: E501

        :return: The organization_id of this OrgRole.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this OrgRole.

        The organization id  # noqa: E501

        :param organization_id: The organization_id of this OrgRole.  # noqa: E501
        :type: str
        """

        self._organization_id = organization_id

    @property
    def permission_ids(self):
        """Gets the permission_ids of this OrgRole.  # noqa: E501


        :return: The permission_ids of this OrgRole.  # noqa: E501
        :rtype: UUIDArray
        """
        return self._permission_ids

    @permission_ids.setter
    def permission_ids(self, permission_ids):
        """Sets the permission_ids of this OrgRole.


        :param permission_ids: The permission_ids of this OrgRole.  # noqa: E501
        :type: UUIDArray
        """

        self._permission_ids = permission_ids

    @property
    def permissions(self):
        """Gets the permissions of this OrgRole.  # noqa: E501


        :return: The permissions of this OrgRole.  # noqa: E501
        :rtype: list[RolePermission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this OrgRole.


        :param permissions: The permissions of this OrgRole.  # noqa: E501
        :type: list[RolePermission]
        """

        self._permissions = permissions

    @property
    def owner(self):
        """Gets the owner of this OrgRole.  # noqa: E501

        Flag is the user role is an owner  # noqa: E501

        :return: The owner of this OrgRole.  # noqa: E501
        :rtype: bool
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this OrgRole.

        Flag is the user role is an owner  # noqa: E501

        :param owner: The owner of this OrgRole.  # noqa: E501
        :type: bool
        """

        self._owner = owner

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrgRole, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrgRole):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Organization(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'slug': 'str',
        'type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'slug': 'slug',
        'type': 'type'
    }

    def __init__(self, id=None, name=None, slug=None, type=None):  # noqa: E501
        """Organization - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._slug = None
        self._type = None
        self.discriminator = None

        self.id = id
        self.name = name
        if slug is not None:
            self.slug = slug
        if type is not None:
            self.type = type

    @property
    def id(self):
        """Gets the id of this Organization.  # noqa: E501


        :return: The id of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Organization.


        :param id: The id of this Organization.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Organization.  # noqa: E501


        :return: The name of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Organization.


        :param name: The name of this Organization.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def slug(self):
        """Gets the slug of this Organization.  # noqa: E501


        :return: The slug of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this Organization.


        :param slug: The slug of this Organization.  # noqa: E501
        :type: str
        """

        self._slug = slug

    @property
    def type(self):
        """Gets the type of this Organization.  # noqa: E501


        :return: The type of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Organization.


        :param type: The type of this Organization.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Organization, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Organization):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.string_array import StringArray  # noqa: F401,E501


class Application(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'organization_id': 'str',
        'name': 'str',
        'client_id': 'str',
        'client_secret': 'str',
        'scope': 'StringArray'
    }

    attribute_map = {
        'id': 'id',
        'organization_id': 'organization_id',
        'name': 'name',
        'client_id': 'client_id',
        'client_secret': 'client_secret',
        'scope': 'scope'
    }

    def __init__(self, id=None, organization_id=None, name=None, client_id=None, client_secret=None, scope=None):  # noqa: E501
        """Application - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._organization_id = None
        self._name = None
        self._client_id = None
        self._client_secret = None
        self._scope = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if organization_id is not None:
            self.organization_id = organization_id
        if name is not None:
            self.name = name
        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if scope is not None:
            self.scope = scope

    @property
    def id(self):
        """Gets the id of this Application.  # noqa: E501


        :return: The id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Application.


        :param id: The id of this Application.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def organization_id(self):
        """Gets the organization_id of this Application.  # noqa: E501

        The organization this application belongs to  # noqa: E501

        :return: The organization_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this Application.

        The organization this application belongs to  # noqa: E501

        :param organization_id: The organization_id of this Application.  # noqa: E501
        :type: str
        """

        self._organization_id = organization_id

    @property
    def name(self):
        """Gets the name of this Application.  # noqa: E501

        The application name  # noqa: E501

        :return: The name of this Application.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Application.

        The application name  # noqa: E501

        :param name: The name of this Application.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def client_id(self):
        """Gets the client_id of this Application.  # noqa: E501

        The client id  # noqa: E501

        :return: The client_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this Application.

        The client id  # noqa: E501

        :param client_id: The client_id of this Application.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this Application.  # noqa: E501

        The client secret  # noqa: E501

        :return: The client_secret of this Application.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this Application.

        The client secret  # noqa: E501

        :param client_secret: The client_secret of this Application.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def scope(self):
        """Gets the scope of this Application.  # noqa: E501


        :return: The scope of this Application.  # noqa: E501
        :rtype: StringArray
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this Application.


        :param scope: The scope of this Application.  # noqa: E501
        :type: StringArray
        """

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Application, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Application):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.reading_data import ReadingData  # noqa: F401,E501


class MicroClimateData(ReadingData):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'humidity': 'float',
        'irrigation_sched': 'int',
        'irrigation_vol_acre_in': 'float',
        'irrigation_vol_acre_cm': 'float',
        'lux': 'float',
        'irrigation_gross_in': 'float',
        'irrigation_net_in': 'float',
        'irrigation_gross_cm': 'float',
        'irrigation_net_cm': 'float',
        'irrigation_rec': 'str',
        'temperature': 'float',
        'eto': 'float',
        'irrigation_stream': 'float',
        'organic_matter': 'float'
    }

    attribute_map = {
        'humidity': 'humidity',
        'irrigation_sched': 'irrigation_sched',
        'irrigation_vol_acre_in': 'irrigation_vol_acre_in',
        'irrigation_vol_acre_cm': 'irrigation_vol_acre_cm',
        'lux': 'lux',
        'irrigation_gross_in': 'irrigation_gross_in',
        'irrigation_net_in': 'irrigation_net_in',
        'irrigation_gross_cm': 'irrigation_gross_cm',
        'irrigation_net_cm': 'irrigation_net_cm',
        'irrigation_rec': 'irrigation_rec',
        'temperature': 'temperature',
        'eto': 'eto',
        'irrigation_stream': 'irrigation_stream',
        'organic_matter': 'organic_matter'
    }

    def __init__(self, humidity=None, irrigation_sched=None, irrigation_vol_acre_in=None, irrigation_vol_acre_cm=None, lux=None, irrigation_gross_in=None, irrigation_net_in=None, irrigation_gross_cm=None, irrigation_net_cm=None, irrigation_rec=None, temperature=None, eto=None, irrigation_stream=None, organic_matter=None):  # noqa: E501
        """MicroClimateData - a model defined in Swagger"""  # noqa: E501

        self._humidity = None
        self._irrigation_sched = None
        self._irrigation_vol_acre_in = None
        self._irrigation_vol_acre_cm = None
        self._lux = None
        self._irrigation_gross_in = None
        self._irrigation_net_in = None
        self._irrigation_gross_cm = None
        self._irrigation_net_cm = None
        self._irrigation_rec = None
        self._temperature = None
        self._eto = None
        self._irrigation_stream = None
        self._organic_matter = None
        self.discriminator = None

        if humidity is not None:
            self.humidity = humidity
        if irrigation_sched is not None:
            self.irrigation_sched = irrigation_sched
        if irrigation_vol_acre_in is not None:
            self.irrigation_vol_acre_in = irrigation_vol_acre_in
        if irrigation_vol_acre_cm is not None:
            self.irrigation_vol_acre_cm = irrigation_vol_acre_cm
        if lux is not None:
            self.lux = lux
        if irrigation_gross_in is not None:
            self.irrigation_gross_in = irrigation_gross_in
        if irrigation_net_in is not None:
            self.irrigation_net_in = irrigation_net_in
        if irrigation_gross_cm is not None:
            self.irrigation_gross_cm = irrigation_gross_cm
        if irrigation_net_cm is not None:
            self.irrigation_net_cm = irrigation_net_cm
        if irrigation_rec is not None:
            self.irrigation_rec = irrigation_rec
        if temperature is not None:
            self.temperature = temperature
        if eto is not None:
            self.eto = eto
        if irrigation_stream is not None:
            self.irrigation_stream = irrigation_stream
        if organic_matter is not None:
            self.organic_matter = organic_matter

    @property
    def humidity(self):
        """Gets the humidity of this MicroClimateData.  # noqa: E501


        :return: The humidity of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._humidity

    @humidity.setter
    def humidity(self, humidity):
        """Sets the humidity of this MicroClimateData.


        :param humidity: The humidity of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._humidity = humidity

    @property
    def irrigation_sched(self):
        """Gets the irrigation_sched of this MicroClimateData.  # noqa: E501

        Irrigation Schedule  # noqa: E501

        :return: The irrigation_sched of this MicroClimateData.  # noqa: E501
        :rtype: int
        """
        return self._irrigation_sched

    @irrigation_sched.setter
    def irrigation_sched(self, irrigation_sched):
        """Sets the irrigation_sched of this MicroClimateData.

        Irrigation Schedule  # noqa: E501

        :param irrigation_sched: The irrigation_sched of this MicroClimateData.  # noqa: E501
        :type: int
        """

        self._irrigation_sched = irrigation_sched

    @property
    def irrigation_vol_acre_in(self):
        """Gets the irrigation_vol_acre_in of this MicroClimateData.  # noqa: E501

        Irrigation volume in3/acre  # noqa: E501

        :return: The irrigation_vol_acre_in of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_vol_acre_in

    @irrigation_vol_acre_in.setter
    def irrigation_vol_acre_in(self, irrigation_vol_acre_in):
        """Sets the irrigation_vol_acre_in of this MicroClimateData.

        Irrigation volume in3/acre  # noqa: E501

        :param irrigation_vol_acre_in: The irrigation_vol_acre_in of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_vol_acre_in = irrigation_vol_acre_in

    @property
    def irrigation_vol_acre_cm(self):
        """Gets the irrigation_vol_acre_cm of this MicroClimateData.  # noqa: E501

        Irrigation volume c3/acre  # noqa: E501

        :return: The irrigation_vol_acre_cm of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_vol_acre_cm

    @irrigation_vol_acre_cm.setter
    def irrigation_vol_acre_cm(self, irrigation_vol_acre_cm):
        """Sets the irrigation_vol_acre_cm of this MicroClimateData.

        Irrigation volume c3/acre  # noqa: E501

        :param irrigation_vol_acre_cm: The irrigation_vol_acre_cm of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_vol_acre_cm = irrigation_vol_acre_cm

    @property
    def lux(self):
        """Gets the lux of this MicroClimateData.  # noqa: E501


        :return: The lux of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._lux

    @lux.setter
    def lux(self, lux):
        """Sets the lux of this MicroClimateData.


        :param lux: The lux of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._lux = lux

    @property
    def irrigation_gross_in(self):
        """Gets the irrigation_gross_in of this MicroClimateData.  # noqa: E501

        Gross irrigation in in3  # noqa: E501

        :return: The irrigation_gross_in of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_gross_in

    @irrigation_gross_in.setter
    def irrigation_gross_in(self, irrigation_gross_in):
        """Sets the irrigation_gross_in of this MicroClimateData.

        Gross irrigation in in3  # noqa: E501

        :param irrigation_gross_in: The irrigation_gross_in of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_gross_in = irrigation_gross_in

    @property
    def irrigation_net_in(self):
        """Gets the irrigation_net_in of this MicroClimateData.  # noqa: E501

        Net irrigation in in3  # noqa: E501

        :return: The irrigation_net_in of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_net_in

    @irrigation_net_in.setter
    def irrigation_net_in(self, irrigation_net_in):
        """Sets the irrigation_net_in of this MicroClimateData.

        Net irrigation in in3  # noqa: E501

        :param irrigation_net_in: The irrigation_net_in of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_net_in = irrigation_net_in

    @property
    def irrigation_gross_cm(self):
        """Gets the irrigation_gross_cm of this MicroClimateData.  # noqa: E501

        Gross irrigation in cm3  # noqa: E501

        :return: The irrigation_gross_cm of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_gross_cm

    @irrigation_gross_cm.setter
    def irrigation_gross_cm(self, irrigation_gross_cm):
        """Sets the irrigation_gross_cm of this MicroClimateData.

        Gross irrigation in cm3  # noqa: E501

        :param irrigation_gross_cm: The irrigation_gross_cm of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_gross_cm = irrigation_gross_cm

    @property
    def irrigation_net_cm(self):
        """Gets the irrigation_net_cm of this MicroClimateData.  # noqa: E501

        Net irrigation in cm3  # noqa: E501

        :return: The irrigation_net_cm of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_net_cm

    @irrigation_net_cm.setter
    def irrigation_net_cm(self, irrigation_net_cm):
        """Sets the irrigation_net_cm of this MicroClimateData.

        Net irrigation in cm3  # noqa: E501

        :param irrigation_net_cm: The irrigation_net_cm of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_net_cm = irrigation_net_cm

    @property
    def irrigation_rec(self):
        """Gets the irrigation_rec of this MicroClimateData.  # noqa: E501

        Irrigation recommendation  # noqa: E501

        :return: The irrigation_rec of this MicroClimateData.  # noqa: E501
        :rtype: str
        """
        return self._irrigation_rec

    @irrigation_rec.setter
    def irrigation_rec(self, irrigation_rec):
        """Sets the irrigation_rec of this MicroClimateData.

        Irrigation recommendation  # noqa: E501

        :param irrigation_rec: The irrigation_rec of this MicroClimateData.  # noqa: E501
        :type: str
        """

        self._irrigation_rec = irrigation_rec

    @property
    def temperature(self):
        """Gets the temperature of this MicroClimateData.  # noqa: E501

        Air Temperature  # noqa: E501

        :return: The temperature of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this MicroClimateData.

        Air Temperature  # noqa: E501

        :param temperature: The temperature of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def eto(self):
        """Gets the eto of this MicroClimateData.  # noqa: E501

        Evaporative Transpiration  # noqa: E501

        :return: The eto of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._eto

    @eto.setter
    def eto(self, eto):
        """Sets the eto of this MicroClimateData.

        Evaporative Transpiration  # noqa: E501

        :param eto: The eto of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._eto = eto

    @property
    def irrigation_stream(self):
        """Gets the irrigation_stream of this MicroClimateData.  # noqa: E501


        :return: The irrigation_stream of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_stream

    @irrigation_stream.setter
    def irrigation_stream(self, irrigation_stream):
        """Sets the irrigation_stream of this MicroClimateData.


        :param irrigation_stream: The irrigation_stream of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_stream = irrigation_stream

    @property
    def organic_matter(self):
        """Gets the organic_matter of this MicroClimateData.  # noqa: E501

        Organic Matter  # noqa: E501

        :return: The organic_matter of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._organic_matter

    @organic_matter.setter
    def organic_matter(self, organic_matter):
        """Sets the organic_matter of this MicroClimateData.

        Organic Matter  # noqa: E501

        :param organic_matter: The organic_matter of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._organic_matter = organic_matter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MicroClimateData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MicroClimateData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Probe(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'serial_code': 'str',
        'field_id': 'str',
        'organization_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'serial_code': 'serial_code',
        'field_id': 'field_id',
        'organization_id': 'organization_id'
    }

    def __init__(self, id=None, serial_code=None, field_id=None, organization_id=None):  # noqa: E501
        """Probe - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._serial_code = None
        self._field_id = None
        self._organization_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if serial_code is not None:
            self.serial_code = serial_code
        if field_id is not None:
            self.field_id = field_id
        if organization_id is not None:
            self.organization_id = organization_id

    @property
    def id(self):
        """Gets the id of this Probe.  # noqa: E501


        :return: The id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Probe.


        :param id: The id of this Probe.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def serial_code(self):
        """Gets the serial_code of this Probe.  # noqa: E501


        :return: The serial_code of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._serial_code

    @serial_code.setter
    def serial_code(self, serial_code):
        """Sets the serial_code of this Probe.


        :param serial_code: The serial_code of this Probe.  # noqa: E501
        :type: str
        """

        self._serial_code = serial_code

    @property
    def field_id(self):
        """Gets the field_id of this Probe.  # noqa: E501


        :return: The field_id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Probe.


        :param field_id: The field_id of this Probe.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def organization_id(self):
        """Gets the organization_id of this Probe.  # noqa: E501


        :return: The organization_id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this Probe.


        :param organization_id: The organization_id of this Probe.  # noqa: E501
        :type: str
        """

        self._organization_id = organization_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Probe, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Probe):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.models.user import User  # noqa: E501
from teralytic.rest import ApiException


class TestUser(unittest.TestCase):
    """User unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUser(self):
        """Test User"""
        # FIXME: construct object with mandatory attributes with example values
        # model = teralytic.models.user.User()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.api.readings_api import ReadingsApi  # noqa: E501
from teralytic.rest import ApiException


class TestReadingsApi(unittest.TestCase):
    """ReadingsApi unit test stubs"""

    def setUp(self):
        self.api = teralytic.api.readings_api.ReadingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_analytics_query(self):
        """Test case for analytics_query

        Query reading anlaytics  # noqa: E501
        """
        pass

    def test_readings_query(self):
        """Test case for readings_query

        Query sensor readings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.field_geometry_geometry import FieldGeometryGeometry  # noqa: F401,E501


class FieldGeometry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'type': 'str',
        'geometry': 'FieldGeometryGeometry'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'geometry': 'geometry'
    }

    def __init__(self, id=None, type=None, geometry=None):  # noqa: E501
        """FieldGeometry - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._type = None
        self._geometry = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if geometry is not None:
            self.geometry = geometry

    @property
    def id(self):
        """Gets the id of this FieldGeometry.  # noqa: E501


        :return: The id of this FieldGeometry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FieldGeometry.


        :param id: The id of this FieldGeometry.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this FieldGeometry.  # noqa: E501


        :return: The type of this FieldGeometry.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FieldGeometry.


        :param type: The type of this FieldGeometry.  # noqa: E501
        :type: str
        """
        allowed_values = ["Feature"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def geometry(self):
        """Gets the geometry of this FieldGeometry.  # noqa: E501


        :return: The geometry of this FieldGeometry.  # noqa: E501
        :rtype: FieldGeometryGeometry
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this FieldGeometry.


        :param geometry: The geometry of this FieldGeometry.  # noqa: E501
        :type: FieldGeometryGeometry
        """

        self._geometry = geometry

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FieldGeometry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldGeometry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teralytic.api_client import ApiClient


class ReadingsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def analytics_query(self, organization_id, **kwargs):  # noqa: E501
        """Query reading anlaytics  # noqa: E501

        Queries readings and performs anayltics operations on the them over a sample  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.analytics_query(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param datetime start_date: Start date and time for the query in RFC3339 format
        :param datetime end_date: End date and time for the query in RFC3339 format
        :param list[str] fields: The fields to return readings for
        :param list[str] probes: The probes to return readings for
        :param list[str] properties: The properties to return readings for
        :param str operation: Operation to perform on reading data
        :param str sample_rate: The operation sample interval, i.e. `15m`
        :param int limit: limit the number of returns per depth
        :param bool extended: Return extended attributes
        :param bool sort: return a sorted array, will decrease performance
        :return: list[Reading]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.analytics_query_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.analytics_query_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def analytics_query_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """Query reading anlaytics  # noqa: E501

        Queries readings and performs anayltics operations on the them over a sample  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.analytics_query_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param datetime start_date: Start date and time for the query in RFC3339 format
        :param datetime end_date: End date and time for the query in RFC3339 format
        :param list[str] fields: The fields to return readings for
        :param list[str] probes: The probes to return readings for
        :param list[str] properties: The properties to return readings for
        :param str operation: Operation to perform on reading data
        :param str sample_rate: The operation sample interval, i.e. `15m`
        :param int limit: limit the number of returns per depth
        :param bool extended: Return extended attributes
        :param bool sort: return a sorted array, will decrease performance
        :return: list[Reading]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'start_date', 'end_date', 'fields', 'probes', 'properties', 'operation', 'sample_rate', 'limit', 'extended', 'sort']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method analytics_query" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `analytics_query`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501
            collection_formats['fields'] = 'csv'  # noqa: E501
        if 'probes' in params:
            query_params.append(('probes', params['probes']))  # noqa: E501
            collection_formats['probes'] = 'csv'  # noqa: E501
        if 'properties' in params:
            query_params.append(('properties', params['properties']))  # noqa: E501
            collection_formats['properties'] = 'csv'  # noqa: E501
        if 'operation' in params:
            query_params.append(('operation', params['operation']))  # noqa: E501
        if 'sample_rate' in params:
            query_params.append(('sample_rate', params['sample_rate']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'extended' in params:
            query_params.append(('extended', params['extended']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/analytics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Reading]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def readings_query(self, organization_id, **kwargs):  # noqa: E501
        """Query sensor readings  # noqa: E501

        Query sensor readings associated with organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.readings_query(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param datetime start_date: Start date and time for the query in RFC3339 format, the default is 24h prior 
        :param datetime end_date: End date and time for the query in RFC3339 format, the implied default is now 
        :param list[str] fields: The fields to return readings for
        :param list[str] probes: The probes to return readings for
        :param list[str] properties: The properties to return readings for
        :param bool extended: Return extended attributes
        :return: list[Reading]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.readings_query_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.readings_query_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def readings_query_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """Query sensor readings  # noqa: E501

        Query sensor readings associated with organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.readings_query_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: id of Organization to retrieve (required)
        :param datetime start_date: Start date and time for the query in RFC3339 format, the default is 24h prior 
        :param datetime end_date: End date and time for the query in RFC3339 format, the implied default is now 
        :param list[str] fields: The fields to return readings for
        :param list[str] probes: The probes to return readings for
        :param list[str] properties: The properties to return readings for
        :param bool extended: Return extended attributes
        :return: list[Reading]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'start_date', 'end_date', 'fields', 'probes', 'properties', 'extended']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method readings_query" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `readings_query`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501
            collection_formats['fields'] = 'csv'  # noqa: E501
        if 'probes' in params:
            query_params.append(('probes', params['probes']))  # noqa: E501
            collection_formats['probes'] = 'csv'  # noqa: E501
        if 'properties' in params:
            query_params.append(('properties', params['properties']))  # noqa: E501
            collection_formats['properties'] = 'csv'  # noqa: E501
        if 'extended' in params:
            query_params.append(('extended', params['extended']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/readings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Reading]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.reading_data import ReadingData  # noqa: F401,E501


class SensorData(ReadingData):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depth': 'int',
        'depth_units': 'str',
        'terascore': 'float',
        'nitrogen': 'float',
        'nitrogen_ppm': 'float',
        'phosphorus': 'float',
        'phosphorus_ppm': 'float',
        'potassium': 'float',
        'potassium_ppm': 'float',
        'ec': 'float',
        'o2': 'float',
        'p_h': 'float',
        'co2': 'float',
        'awc': 'float',
        'soil_moisture': 'float',
        'soil_temperature': 'float',
        'soil_texture': 'str',
        'extended_attributes': 'dict(str, object)'
    }

    attribute_map = {
        'depth': 'depth',
        'depth_units': 'depth_units',
        'terascore': 'terascore',
        'nitrogen': 'nitrogen',
        'nitrogen_ppm': 'nitrogen_ppm',
        'phosphorus': 'phosphorus',
        'phosphorus_ppm': 'phosphorus_ppm',
        'potassium': 'potassium',
        'potassium_ppm': 'potassium_ppm',
        'ec': 'ec',
        'o2': 'o2',
        'p_h': 'pH',
        'co2': 'co2',
        'awc': 'awc',
        'soil_moisture': 'soil_moisture',
        'soil_temperature': 'soil_temperature',
        'soil_texture': 'soil_texture',
        'extended_attributes': 'extended_attributes'
    }

    def __init__(self, depth=None, depth_units=None, terascore=None, nitrogen=None, nitrogen_ppm=None, phosphorus=None, phosphorus_ppm=None, potassium=None, potassium_ppm=None, ec=None, o2=None, p_h=None, co2=None, awc=None, soil_moisture=None, soil_temperature=None, soil_texture=None, extended_attributes=None):  # noqa: E501
        """SensorData - a model defined in Swagger"""  # noqa: E501

        self._depth = None
        self._depth_units = None
        self._terascore = None
        self._nitrogen = None
        self._nitrogen_ppm = None
        self._phosphorus = None
        self._phosphorus_ppm = None
        self._potassium = None
        self._potassium_ppm = None
        self._ec = None
        self._o2 = None
        self._p_h = None
        self._co2 = None
        self._awc = None
        self._soil_moisture = None
        self._soil_temperature = None
        self._soil_texture = None
        self._extended_attributes = None
        self.discriminator = None

        if depth is not None:
            self.depth = depth
        if depth_units is not None:
            self.depth_units = depth_units
        if terascore is not None:
            self.terascore = terascore
        if nitrogen is not None:
            self.nitrogen = nitrogen
        if nitrogen_ppm is not None:
            self.nitrogen_ppm = nitrogen_ppm
        if phosphorus is not None:
            self.phosphorus = phosphorus
        if phosphorus_ppm is not None:
            self.phosphorus_ppm = phosphorus_ppm
        if potassium is not None:
            self.potassium = potassium
        if potassium_ppm is not None:
            self.potassium_ppm = potassium_ppm
        if ec is not None:
            self.ec = ec
        if o2 is not None:
            self.o2 = o2
        if p_h is not None:
            self.p_h = p_h
        if co2 is not None:
            self.co2 = co2
        if awc is not None:
            self.awc = awc
        if soil_moisture is not None:
            self.soil_moisture = soil_moisture
        if soil_temperature is not None:
            self.soil_temperature = soil_temperature
        if soil_texture is not None:
            self.soil_texture = soil_texture
        if extended_attributes is not None:
            self.extended_attributes = extended_attributes

    @property
    def depth(self):
        """Gets the depth of this SensorData.  # noqa: E501

        The depth value  # noqa: E501

        :return: The depth of this SensorData.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this SensorData.

        The depth value  # noqa: E501

        :param depth: The depth of this SensorData.  # noqa: E501
        :type: int
        """

        self._depth = depth

    @property
    def depth_units(self):
        """Gets the depth_units of this SensorData.  # noqa: E501

        The depth units (i.e. in, cm)  # noqa: E501

        :return: The depth_units of this SensorData.  # noqa: E501
        :rtype: str
        """
        return self._depth_units

    @depth_units.setter
    def depth_units(self, depth_units):
        """Sets the depth_units of this SensorData.

        The depth units (i.e. in, cm)  # noqa: E501

        :param depth_units: The depth_units of this SensorData.  # noqa: E501
        :type: str
        """

        self._depth_units = depth_units

    @property
    def terascore(self):
        """Gets the terascore of this SensorData.  # noqa: E501

        TeraScore  # noqa: E501

        :return: The terascore of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._terascore

    @terascore.setter
    def terascore(self, terascore):
        """Sets the terascore of this SensorData.

        TeraScore  # noqa: E501

        :param terascore: The terascore of this SensorData.  # noqa: E501
        :type: float
        """

        self._terascore = terascore

    @property
    def nitrogen(self):
        """Gets the nitrogen of this SensorData.  # noqa: E501

        Nitrogen  # noqa: E501

        :return: The nitrogen of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._nitrogen

    @nitrogen.setter
    def nitrogen(self, nitrogen):
        """Sets the nitrogen of this SensorData.

        Nitrogen  # noqa: E501

        :param nitrogen: The nitrogen of this SensorData.  # noqa: E501
        :type: float
        """

        self._nitrogen = nitrogen

    @property
    def nitrogen_ppm(self):
        """Gets the nitrogen_ppm of this SensorData.  # noqa: E501

        Nitrogen ppm  # noqa: E501

        :return: The nitrogen_ppm of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._nitrogen_ppm

    @nitrogen_ppm.setter
    def nitrogen_ppm(self, nitrogen_ppm):
        """Sets the nitrogen_ppm of this SensorData.

        Nitrogen ppm  # noqa: E501

        :param nitrogen_ppm: The nitrogen_ppm of this SensorData.  # noqa: E501
        :type: float
        """

        self._nitrogen_ppm = nitrogen_ppm

    @property
    def phosphorus(self):
        """Gets the phosphorus of this SensorData.  # noqa: E501

        Phosphorus  # noqa: E501

        :return: The phosphorus of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._phosphorus

    @phosphorus.setter
    def phosphorus(self, phosphorus):
        """Sets the phosphorus of this SensorData.

        Phosphorus  # noqa: E501

        :param phosphorus: The phosphorus of this SensorData.  # noqa: E501
        :type: float
        """

        self._phosphorus = phosphorus

    @property
    def phosphorus_ppm(self):
        """Gets the phosphorus_ppm of this SensorData.  # noqa: E501

        Phosphorus ppm  # noqa: E501

        :return: The phosphorus_ppm of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._phosphorus_ppm

    @phosphorus_ppm.setter
    def phosphorus_ppm(self, phosphorus_ppm):
        """Sets the phosphorus_ppm of this SensorData.

        Phosphorus ppm  # noqa: E501

        :param phosphorus_ppm: The phosphorus_ppm of this SensorData.  # noqa: E501
        :type: float
        """

        self._phosphorus_ppm = phosphorus_ppm

    @property
    def potassium(self):
        """Gets the potassium of this SensorData.  # noqa: E501

        Potassium  # noqa: E501

        :return: The potassium of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._potassium

    @potassium.setter
    def potassium(self, potassium):
        """Sets the potassium of this SensorData.

        Potassium  # noqa: E501

        :param potassium: The potassium of this SensorData.  # noqa: E501
        :type: float
        """

        self._potassium = potassium

    @property
    def potassium_ppm(self):
        """Gets the potassium_ppm of this SensorData.  # noqa: E501

        Potassium ppm  # noqa: E501

        :return: The potassium_ppm of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._potassium_ppm

    @potassium_ppm.setter
    def potassium_ppm(self, potassium_ppm):
        """Sets the potassium_ppm of this SensorData.

        Potassium ppm  # noqa: E501

        :param potassium_ppm: The potassium_ppm of this SensorData.  # noqa: E501
        :type: float
        """

        self._potassium_ppm = potassium_ppm

    @property
    def ec(self):
        """Gets the ec of this SensorData.  # noqa: E501

        Electrical Conductivity  # noqa: E501

        :return: The ec of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._ec

    @ec.setter
    def ec(self, ec):
        """Sets the ec of this SensorData.

        Electrical Conductivity  # noqa: E501

        :param ec: The ec of this SensorData.  # noqa: E501
        :type: float
        """

        self._ec = ec

    @property
    def o2(self):
        """Gets the o2 of this SensorData.  # noqa: E501

        Dioxygen  # noqa: E501

        :return: The o2 of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._o2

    @o2.setter
    def o2(self, o2):
        """Sets the o2 of this SensorData.

        Dioxygen  # noqa: E501

        :param o2: The o2 of this SensorData.  # noqa: E501
        :type: float
        """

        self._o2 = o2

    @property
    def p_h(self):
        """Gets the p_h of this SensorData.  # noqa: E501

        pH Scale  # noqa: E501

        :return: The p_h of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._p_h

    @p_h.setter
    def p_h(self, p_h):
        """Sets the p_h of this SensorData.

        pH Scale  # noqa: E501

        :param p_h: The p_h of this SensorData.  # noqa: E501
        :type: float
        """

        self._p_h = p_h

    @property
    def co2(self):
        """Gets the co2 of this SensorData.  # noqa: E501

        Carbon Dioxide  # noqa: E501

        :return: The co2 of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._co2

    @co2.setter
    def co2(self, co2):
        """Sets the co2 of this SensorData.

        Carbon Dioxide  # noqa: E501

        :param co2: The co2 of this SensorData.  # noqa: E501
        :type: float
        """

        self._co2 = co2

    @property
    def awc(self):
        """Gets the awc of this SensorData.  # noqa: E501


        :return: The awc of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._awc

    @awc.setter
    def awc(self, awc):
        """Sets the awc of this SensorData.


        :param awc: The awc of this SensorData.  # noqa: E501
        :type: float
        """

        self._awc = awc

    @property
    def soil_moisture(self):
        """Gets the soil_moisture of this SensorData.  # noqa: E501

        Soil Moisture  # noqa: E501

        :return: The soil_moisture of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._soil_moisture

    @soil_moisture.setter
    def soil_moisture(self, soil_moisture):
        """Sets the soil_moisture of this SensorData.

        Soil Moisture  # noqa: E501

        :param soil_moisture: The soil_moisture of this SensorData.  # noqa: E501
        :type: float
        """

        self._soil_moisture = soil_moisture

    @property
    def soil_temperature(self):
        """Gets the soil_temperature of this SensorData.  # noqa: E501

        Soil Temperature  # noqa: E501

        :return: The soil_temperature of this SensorData.  # noqa: E501
        :rtype: float
        """
        return self._soil_temperature

    @soil_temperature.setter
    def soil_temperature(self, soil_temperature):
        """Sets the soil_temperature of this SensorData.

        Soil Temperature  # noqa: E501

        :param soil_temperature: The soil_temperature of this SensorData.  # noqa: E501
        :type: float
        """

        self._soil_temperature = soil_temperature

    @property
    def soil_texture(self):
        """Gets the soil_texture of this SensorData.  # noqa: E501

        Soil texture type. Data are collected from government data sources (USDA's SSURGO database for fields in the United States)  # noqa: E501

        :return: The soil_texture of this SensorData.  # noqa: E501
        :rtype: str
        """
        return self._soil_texture

    @soil_texture.setter
    def soil_texture(self, soil_texture):
        """Sets the soil_texture of this SensorData.

        Soil texture type. Data are collected from government data sources (USDA's SSURGO database for fields in the United States)  # noqa: E501

        :param soil_texture: The soil_texture of this SensorData.  # noqa: E501
        :type: str
        """

        self._soil_texture = soil_texture

    @property
    def extended_attributes(self):
        """Gets the extended_attributes of this SensorData.  # noqa: E501

        Additional properties  # noqa: E501

        :return: The extended_attributes of this SensorData.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extended_attributes

    @extended_attributes.setter
    def extended_attributes(self, extended_attributes):
        """Sets the extended_attributes of this SensorData.

        Additional properties  # noqa: E501

        :param extended_attributes: The extended_attributes of this SensorData.  # noqa: E501
        :type: dict(str, object)
        """

        self._extended_attributes = extended_attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SensorData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SensorData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from teralytic.api.organization_api import OrganizationApi
from teralytic.api.readings_api import ReadingsApi

# import ApiClient
from teralytic.api_client import ApiClient
from teralytic.configuration import Configuration
# import models into sdk package
from teralytic.models.application import Application
from teralytic.models.error import Error
from teralytic.models.field import Field
from teralytic.models.field_geometry import FieldGeometry
from teralytic.models.field_geometry_geometry import FieldGeometryGeometry
from teralytic.models.org_role import OrgRole
from teralytic.models.organization import Organization
from teralytic.models.probe import Probe
from teralytic.models.property_role import PropertyRole
from teralytic.models.reading import Reading
from teralytic.models.reading_data import ReadingData
from teralytic.models.reading_location import ReadingLocation
from teralytic.models.reading_type import ReadingType
from teralytic.models.role_permission import RolePermission
from teralytic.models.string_array import StringArray
from teralytic.models.uuid_array import UUIDArray
from teralytic.models.user import User
from teralytic.models.micro_climate_data import MicroClimateData
from teralytic.models.sensor_data import SensorData
from teralytic.models.weather_data import WeatherData



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "teralytic"
VERSION = "1.0.6-6"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="teralytic",
    author_email="rob@modelrocket.io",
    url="",
    keywords=["Swagger", "teralytic"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: &#x60;swagger.teralytic.io&#x60;   # noqa: E501
    """
)
